## PyRemoteSQLite - Python wrapper for RemoteSQLite API

### Usage:
1. Install package via pip: `pip3 install pyremsql`
2. Import it: `import pyremsql`
3. Use available functions. For most of the functionality, check `test.py`